aboutsummaryrefslogtreecommitdiff
path: root/modules
diff options
context:
space:
mode:
authorAlex Neundorf <neundorf@kde.org>2011-09-21 07:36:24 +0200
committerAlex Neundorf <neundorf@kde.org>2011-09-21 07:36:24 +0200
commit2a3a5e7033d71a8466d96038c030c28459d861b8 (patch)
tree0e413f71a2a6f4cbea4fc2bafc1006e0d3d80fa4 /modules
parent6e3b6f44af3650ed39e72b85cf52063b45a9dfb6 (diff)
downloadextra-cmake-modules-2a3a5e7033d71a8466d96038c030c28459d861b8.tar.gz
extra-cmake-modules-2a3a5e7033d71a8466d96038c030c28459d861b8.tar.bz2
-some minor polishing of FindBlueZ.cmake
Alex
Diffstat (limited to 'modules')
-rw-r--r--modules/FindBlueZ.cmake27
1 files changed, 10 insertions, 17 deletions
diff --git a/modules/FindBlueZ.cmake b/modules/FindBlueZ.cmake
index b1577d31..74e33a56 100644
--- a/modules/FindBlueZ.cmake
+++ b/modules/FindBlueZ.cmake
@@ -1,4 +1,4 @@
-# - Try to find BlueZ
+# - Try to find BlueZ bluetooth library.
# Once done this will define
#
# BLUEZ_FOUND - system has BlueZ
@@ -15,20 +15,12 @@
# For details see the accompanying COPYING-CMAKE-SCRIPTS file.
-if ( BLUEZ_INCLUDE_DIR AND BLUEZ_LIBRARIES )
- # in cache already
- set(BlueZ_FIND_QUIETLY TRUE)
-endif ( BLUEZ_INCLUDE_DIR AND BLUEZ_LIBRARIES )
-
# use pkg-config to get the directories and then use these values
# in the FIND_PATH() and FIND_LIBRARY() calls
-if( NOT WIN32 )
- find_package(PkgConfig)
-
- pkg_check_modules(PC_BLUEZ QUIET bluez)
+find_package(PkgConfig)
+pkg_check_modules(PC_BLUEZ QUIET bluez)
- set(BLUEZ_DEFINITIONS ${PC_BLUEZ_CFLAGS_OTHER})
-endif( NOT WIN32 )
+set(BLUEZ_DEFINITIONS ${PC_BLUEZ_CFLAGS_OTHER})
find_path(BLUEZ_INCLUDE_DIR NAMES bluetooth/bluetooth.h
PATHS
@@ -37,15 +29,16 @@ find_path(BLUEZ_INCLUDE_DIR NAMES bluetooth/bluetooth.h
/usr/X11/include
)
-find_library(BLUEZ_LIBRARIES NAMES bluetooth
+find_library(BLUEZ_LIBRARY NAMES bluetooth
PATHS
${PC_BLUEZ_LIBDIR}
${PC_BLUEZ_LIBRARY_DIRS}
)
-include(FindPackageHandleStandardArgs)
-find_package_handle_standard_args(BlueZ DEFAULT_MSG BLUEZ_INCLUDE_DIR BLUEZ_LIBRARIES )
+set(BLUEZ_LIBRARIES ${BLUEZ_LIBRARY} )
-# show the BLUEZ_INCLUDE_DIR and BLUEZ_LIBRARIES variables only in the advanced view
-mark_as_advanced(BLUEZ_INCLUDE_DIR BLUEZ_LIBRARIES )
+include(FindPackageHandleStandardArgs)
+find_package_handle_standard_args(BlueZ DEFAULT_MSG BLUEZ_LIBRARY BLUEZ_INCLUDE_DIR)
+# show the BLUEZ_INCLUDE_DIR and BLUEZ_LIBRARY variables only in the advanced view
+mark_as_advanced(BLUEZ_INCLUDE_DIR BLUEZ_LIBRARY )